==> haskell-resourcet-1.2.2-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.2.2
id: resourcet-1.2.2-njuTV0kmRGB4xSgU2BFrl
key: resourcet-1.2.2-njuTV0kmRGB4xSgU2BFrl
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
abi: 6c58cb43ee78711f46799b2e45252bf9
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource
import-dirs: /usr/lib/ghc-8.6.5/site-local/resourcet-1.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/resourcet-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/resourcet-1.2.2
hs-libraries: HSresourcet-1.2.2-njuTV0kmRGB4xSgU2BFrl
depends:
    base-4.12.0.0 containers-0.6.0.1
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.2.2-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.2.2
id: resourcet-1.2.2-dhy05EaumY7hb7k0cecE5
key: resourcet-1.2.2-dhy05EaumY7hb7k0cecE5
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
abi: 01fc4115f1def056fb4c1681396cdb19
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource
import-dirs: /usr/lib/ghc-8.6.5/site-local/resourcet-1.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/resourcet-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/resourcet-1.2.2
hs-libraries: HSresourcet-1.2.2-dhy05EaumY7hb7k0cecE5
depends:
    base-4.12.0.0 containers-0.6.0.1
    exceptions-0.10.2-9mMpM660ub68KqgVRkcrU mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
